@@ -4,10 +4,10 @@
 ###############################################################################
 
 
-on_appveyor <- function() {
+on_appveyor = function() {
   identical(Sys.getenv("APPVEYOR"), "True")
 }
-on_cran <- function() {
+on_cran = function() {
   !identical(Sys.getenv("NOT_CRAN"), "true")
 }
 
